崖上的波妞 (豆瓣)
Description: 崖上的波妞电影简介和剧情介绍,崖上的波妞影评、图片、预告片、影讯、论坛、在线购票
Keywords: 崖上的波妞,崖の上のポニョ,崖上的波妞影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.226豆瓣电影Top250

# 崖上的波妞 崖の上のポニョ (2008)

导演: 宫崎骏
编剧: 宫崎骏
主演: 神月柚莉爱 / 土井洋辉 / 山口智子 / 长岛一茂 / 天海祐希 / 所乔治 / 柊瑠美 / 矢野显子 / 吉行和子 / 奈良冈朋子 / 左时枝 / 羽鸟慎一 / 平冈映美 / 大桥望美
类型: 动画 / 奇幻 / 冒险
官方网站: www.ghibli.jp/ponyo/
制片国家/地区: 日本
语言: 日语
上映日期: 2020-12-31(中国大陆) / 2008-07-19(日本)
片长: 101分钟
又名: 悬崖上的金鱼姬 / 悬崖上的金鱼公主 / 崖上的波儿(港) / 悬崖上的Ponyo / Ponyo on the Cliff by the Sea / Gake no ue no Ponyo
IMDb: tt0876563
豆瓣评分
引用
8.6
460815人评价
5星
44.7%
4星
42.1%
3星
12.3%
2星
0.8%
1星
0.2%
好于 96% 动画片
好于 97% 奇幻片
想看 看过
评价:
推荐

## 崖上的波妞的剧情简介 · · · · · ·

海神的女儿波妞从深海出逃玩耍，却被困在玻璃瓶里冲到岸上，碰巧被住在岸边悬崖的宗介救出，两人因此相识。但是波妞的父亲——魔法师藤本，认为人类世界肮脏丑陋，强行把波妞带回海里。面对父亲的阻挠、席卷小镇的海啸，以及永远失去魔法的威胁，波妞仍然大胆而坚决地决定——要变成人类跟宗介在一起。而承诺要永远保护波妞的宗介，也即将面临新的挑战...

## 崖上的波妞的演职员 · · · · · · ( 全部 50 )

- 宫崎骏 导演
- 神月柚莉爱 配 波妞 ポニョ Ponyo
- 土井洋辉 配 宗介 Sôsuke
- 山口智子 配 理莎 リサ Risa
- 长岛一茂 配 耕一 Kôichi
- 天海祐希 配 曼玛莲 グランマンマーレ Granmamare

## 崖上的波妞的视频和图片 · · · · · · ( 预告片9 | 添加视频评论 | 图片644 · 添加 )

## 崖上的波妞的获奖情况 · · · · · · ( 全部 )

- 第65届威尼斯电影节
- 金狮奖(提名)
- 宫崎骏

- 第29届香港电影金像奖
- 最佳亚洲电影(提名)

- 第32届日本电影学院奖
- 最佳动画片

## 喜欢这部电影的人也喜欢 · · · · · ·

  天空之城

  幽灵公主

  哈尔的移动城堡

  魔女宅急便

  风之谷

  红猪

  猫的报恩

  起风了

  大闹天宫

  侧耳倾听

我要写短评

## 崖上的波妞的短评 · · · · · · ( 全部 93832 条 )

热门 / 最新 / 好友

### 893 有用 南国玫瑰 看过 2009-05-17 19:08:46

好可爱啊，可爱的波妞，懂爱的宗介

### 2588 有用 欧妮欧妮欧妮 看过 2012-08-31 15:47:10

虽然是不及龙猫，千与千寻，但是17万张的纯手绘…那背景真心好漂亮~而且这个指向就是给小孩子看的！人老了，反而会计较“这到底在表达什么，这到底在讽刺什么？完全不知所云”难道一定要超越前作？一定要深刻的表达什么？他只是单纯的想表达一种不被污染的童真，没有那么多的为什么和逻辑啊

### 1823 有用 焰熠 看过 2018-01-16 21:25:19

谁说5岁就不可以早恋的 波妞为了宗介在海浪上奔跑的样子太可爱了 为了喜欢的人 踏过千山万水又何妨

### 638 有用 我坏故我在 看过 2008-08-05 09:10:26

人物造型和以前的很多片子有类似点，而且还能找到以前片子里的龙套……故事居然是小美人鱼的幼儿版……不过很好看啊很好看啊很好看啊……

### 540 有用 松如 看过 2008-08-31 11:22:11

给五星是因为我爱宫崎骏。。

> 更多短评 93832条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 崖上的波妞的影评 · · · · · · ( 全部 1374 条 )

热门 / 最新 / 好友
小暮 2008-11-06 00:12:19

## 想要问问你敢不敢

你还在看童话吗? 或者说，你还相信那些古老而传统的价值观，相信爱的力量，相信奇迹的存在吗？ 有一段时间，我被那些尽情颠覆，尽情嘲笑，尽情展现人性之黑暗的电影征服了。我以为这才是人生的真相，这才是答案。而那些真善美啊，美好温情啊，牺牲奉献啊，不过是一层甜得发腻... (展开)
2302 69 229回应 收起
十二 2009-07-30 11:14:20

## 波妞，波妞，爱死你那乘风破浪的样子

这篇影评可能有剧透

宫崎骏的电影，绝对是浮生安慰。 尽管波妞，不如之前天空之城、萤火虫，移动城堡那样发人深省，但仍是我的大爱。 到底是什么打动了我们呢？ 没有情话，只有傻呼呼地递一个食物，或者傻呵呵的相视一笑，转身就跑。那么肉乎乎的小肉身拥在一起的时候，谁也不知道这算不算爱，可... (展开)
894 18 107回应 收起
花橘子叔叔 2008-08-04 00:45:18

## 有史以来最可爱的美人鱼公主

为了好吃的火腿，为了5岁的男朋友宗介，波妞勇敢的冲向人间， 观看影片时我脑子里一直都有一个巨大的不祥的阴影笼罩，担心“美人鱼最后会为爱情而牺牲...”这都怪安徒生给我们造成的童年阴影，而让主人公不得善终的事情宫崎骏先生也不是没有干过，会不会又是“再见萤火虫”那... (展开)
611 25 199回应 收起
群青色 2008-07-30 23:53:10

## 金鱼海，水下森林——宫崎骏的完美谢幕

这篇影评可能有剧透

在网络上出现抢先字幕版的第58分钟，我欣喜若狂地将优酷链接发到Q群上和所有人分享我的喜悦。然后静下心来，戴上耳机，跟着宫崎老爷子的画笔，和摇着红色裙摆的ponyo，游入深海。 那一刻，恍惚间我仿佛又坐上了那班旧旧的海上电车，沿着蓝色海水间细细长长的铁轨，... (展开)
420 12 58回应 收起
孔雷鸥_ 2008-08-01 16:52:52

## 不管爱上什么...都请爱一辈子...

从海的女儿开始...人们就开始推崇无界限的爱恋了...即使你爱上的是一条鱼...从泡沫衍生到回归泡沫的一辈子...人鱼似乎都在憧憬一世一情缘...那人类在追求什么呢... 还记得我们大一外出采风时...和同学们讨论爱情面临的问题...从身高不是问题到长相不是问题再到年龄不是问题种族... (展开)
170 21 106回应 收起
拾叁空城 2008-10-08 16:22:18

## 只有kids才能创造出纯粹的爱情

能够坐下来观看一部宫崎骏的电影，是多好的一件事啊。 他的不可思议在于，你永远不会知道他在电影里将给你带来什么，并且每一次都会让你受益匪浅。 面对这部《悬崖上的金鱼姬》，谁能想到他会让一对五岁的小孩来谈一段彻头彻尾的恋爱呢。它没有好莱坞的噱头与卖... (展开)
142 4 50回应 收起
lolam 2009-01-26 16:51:14

## 自私精

这篇影评可能有剧透

整體來說 感覺情節還沒有展開來 忽然卻完了 明顯在宮老心目中情節doesn't really matter 細節才是重點 最喜歡宮崎駿畫宗介和理紗的段落 如果我有孩子 我想我應該是理紗一樣的媽媽吧… 早上遲到飛車S字駕駛 在路上和孩子一起咬面包 爸爸不回家會發脾氣不煮飯 在宗介幫媽媽打燈... (展开)
95 9 38回应 收起
少楠 Plidezus 2008-08-02 18:58:27

## 宫崎骏老爷子，您回来了！

这篇影评可能有剧透

那么事隔多年后，您还是回来了，带来了那份最纯真的感动。 时间应该倒退到大概一九九七年香港回归后，某个家里没人的夜晚，在那个只有每晚八点才会出现的纱厂电视台中，出现了那个叫希达的女孩子，出现了laputa，出现了那些高架起来的铁轨，出现了那个笨拙而又可怕的机器人。... (展开)
60 1 43回应 收起
🈚️ 2018-05-21 12:54:28

## 我一定要飞奔着去见你

这篇影评可能有剧透

《悬崖上的金鱼姬》是动画大师宫崎骏的又一力作。人物形象可以说是超可爱、超活泼，特别是宗介和波妞。故事情节更是令人感动，就是现代版的浪漫故事。活动环境富有日本岛国特色，动画风格也是明快、简洁、浪漫的。 金鱼姬是一条活泼好动的小鱼，一次偶然的机会，它在涨潮时被冲... (展开)
63 4 2回应 收起
雲生 2008-08-31 01:04:56

## 人和鱼

这篇影评可能有剧透

看完了。 这个故事其实很短，清浅如池水，淹不死人。画风也还是我最熟悉的宫大爷。差点就要叫“龙猫阿”。 去找理纱的路上，波妞困得迷迷瞪瞪的，连魔法也不能使了，宗介拖着她的手在黑暗的隧道里奔跑，发现她不是那个小女孩的样子，变成了半变身的小鸡模样，宗介抱起波妞往海... (展开)
54 1 28回应 收起

> 更多影评 1374篇

添加新讨论

## 讨论区 · · · · · ·

波妞她妈真想得开~ | 来自罐头活鱼 | 21 回应 | 2022-11-18 03:30:11
这部动漫太可爱了！ | 来自小狐狸的帽子 |  | 2022-11-09 13:00:48
小人鱼泡沫就泡沫了 | 来自豆友205786977 |  | 2022-10-14 22:00:09
好看 | 来自不知道叫啥 |  | 2022-10-07 19:47:30
波妞 | 来自kh |  | 2022-09-26 07:59:18

> 去这部影片的讨论区（全部461条）

## 关于《崖上的波妞》的问题 · · · · · · ( 全部14个 )

- 宗介和波妞用的玩具船，原理真的是这样么？ 2人回答
- 那个加了蜂蜜的热饮到底是茶还是汤？怎么做呢？ 0人回答

> 全部14个问题

## 在哪儿看这部电影 · · · · · ·

- 爱奇艺视频 VIP免费观看

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- 【豆瓣高分动画长片】 (影志)
- 那些牛叉闪闪的片子 (家庭种菜笔记)
- 【大爱の日剧♂电影♀动画全收录】 (狷介有乌青)
- 治愈系动画推荐 ([己注销])
- 【爱看动画】 (影志)

## 谁在看这部电影 · · · · · ·

- pupuさん
  7分钟前 看过
- Shdevy
  8分钟前 看过
- 想不出来呀
  10分钟前 看过

864314人看过 / 167362人想看

订阅崖上的波妞的评论:
feed: rss 2.0